"use client";

import React, { useEffect, useState } from 'react';
import Web3 from 'web3';
import { Container, Typography, Card, CardContent, List, ListItem, Paper, Grid } from '@mui/material';
import { useRouter } from 'next/navigation';

import NavBar from '../components/NavBar';
import { checkConnectionMetaMask, getAuctionContract } from '../utils';

const AuctionList = () => {
    const [auctions, setAuctions] = useState([]);
    const { auctionContract, web3 } = getAuctionContract();
    const router = useRouter();

    useEffect(() => {
        const fetchItemsAvailable = async () => {
            const accounts = await checkConnectionMetaMask();
            if (accounts.length === 0) {
                router.push('/');
            } else {
                try {
                    const availableAuctions = await auctionContract.methods.getAllAuctionItems().call();
                    console.log('Available Auctions:', availableAuctions);

                    setAuctions(availableAuctions);
                } catch (error) {
                    console.error('Error fetching available auctions:', error);
                    setAuctions([]);
                }
            }
        };

        fetchItemsAvailable();
    }, []);

    const formatTimestamp = (timestamp) => {
        const date = new Date(Number(timestamp) * 1000);
        const formattedDate = date.toLocaleString('fr-FR');
        return formattedDate;
    };

    return (
        <>
            <NavBar />
            <Container>
                <Typography variant="h2">Liste des Enchères Disponibles</Typography>
                <Paper elevation={3}>
                    <List>
                        {auctions.map((auction, index) => (
                            <ListItem key={index}>
                                <Card>
                                    <CardContent>
                                        <Typography variant="subtitle1">
                                            Nom: {auction.name}
                                            <br />
                                            Prix: {web3.utils.fromWei(auction.price.toString(), 'ether')} Ether
                                            <br />
                                            Timestamp: {formatTimestamp(auction.timestamp)}
                                            <br />
                                            Statut: {auction.status}
                                        </Typography>
                                    </CardContent>
                                </Card>
                            </ListItem>
                        ))}
                    </List>
                </Paper>
            </Container>
        </>
    );
};

export default AuctionList;
